@@ -45,8 +45,8 @@ class OrderSignal(DeserializableObject):
     def isExecuted(self):
         return self.__isSignalExecuted
 
-    def executedCallBack(self):
-        self.__isSignalExecuted = True
+    def executedCallBack(self, result: True):
+        self.__isSignalExecuted = result
 
     def getCondition(self):
         return self.__condition
