@@ -49,3 +49,7 @@ class Conditions(DeserializableObject):
         _condition = Condition(identify, conditionData)
         self.__conditions.append(_condition)
         return _condition
+
+    def append(self, condition: Condition):
+        if condition:
+            self.__conditions.append(condition)
